local inst_link /ssb/ursus/a1/finnut/wk48/inst_link

use  soknad_full, clear

preserve
bysort fnr (pri): keep if _n==1
keep fnr mor_fnr-lnf8yrc peer_pred inst_compl
tempfile indvars
save `indvars'
restore

// drop options with higher thresholds than better ranked ones
g gpamin = .
bysort year fnr (pri): replace gpamin = min(gpabound, gpamin[_n - 1])
bysort year fnr (pri): g dominated = _n > 1 & gpabound >= gpamin[_n - 1]
drop if dominated

rename pri rank
rename studie study
keep year fnr rank study tilbud inst field_* gpa* poffer duration

g d  = gpa - gpabound // forcing variable
g d_orig = d
g dum = (d>=0)
g offer = tilbud=="S"

g poffer_x = poffer
g maxrank = rank
g minrank = rank

// Each "block" of consecutive courses within the same field is replaced with one observation,
// which has forcing variable and rank equal to the min of the courses
local maxvars  poffer offer d maxrank
local minvars  minrank
bysort year fnr (rank): g block = _n
bysort year fnr (rank): replace block = block[_n - 1] if field_agg==field_agg[_n - 1] & field_agg<.
foreach x in max min {
	foreach var of varlist ``x'vars' {
		bysort year fnr block : egen `x'`var' =`x'(`var')
		replace `var' =`x'`var'
		drop `x'`var'
	}
}
replace dum = (d>=0)
sort year fnr block poffer_x d

bysort year fnr block (poffer_x d_orig): keep if _n==_N
drop block

// criterion for (predicted to) being offered a course
bysort year fnr (rank): g offer_pred = gpa>=gpabound & sum(gpa>=gpabound)==1

// Finding counterfactual (cf) fields (what the applicant would
// get were his GPA higher/lower, i.e. do not consider what would happen if
// GPA bound were different)
bysort year fnr : egen rankoffered = max(cond(offer_pred,rank,.))
bysort year fnr : egen gpaboundoffered = max(cond(offer_pred,gpabound,.))
bysort year fnr (rank): g cf1 = rank>rankoffered & gpabound<gpaboundoffered & ///
    sum(rank>rankoffered & gpabound<gpaboundoffered)==1 // the next alternative reducing the applicant's gpa
bysort year fnr (gpabound rank): g cf2 = rank<rankoffered & gpabound>gpaboundoffered & ///
    sum(rank<rankoffered & gpabound>gpaboundoffered)==1 // the next alternative increasing the applicant's gpa
g cf = cf1 | cf2
drop cf1 cf2 // tilbud gpa poffer gpamin poffer_x rankoffered gpaboundof~d

// Makes a data set of all possible actual - counterfactual pairs:
ds year fnr, not
rename (`r(varlist)') =_f0 
tempfile study_f0
save `study_f0'

rename (*_f0) (*_f1)
joinby year fnr using `study_f0'

// Keeps only the relevant pairs:
keep if rank_f1 < rank_f0             // f1 is the most-preferred
keep if offer_pred_f1 | offer_pred_f0 // only obs offered f1 or f0
keep if cf_f1 | cf_f0                 // only closest counterfactual obs

keep fnr year *f1 *f0 
compress
bys fnr year (rank_f1) : keep if _n==1 // retains most-preferred margin for applicants with two possible f1/f0 margins

rename year appyear
label var appyear "year of application"
rename gpa_f1 gpa

merge 1:1 fnr using `indvars' ,nogen keep(1 3)

// Controls
g pred_exp = 8-cond(dum_f1,duration_f1,duration_f0)

g gpa2 = gpa^2
g gpa3 = gpa^3

* Age and year variables
qui g orig_age = age
qui replace age = 40 if age>39
qui replace age = 30 if inrange(age,30,39)
qui replace age = 18 if age==17

g sample = field_agg_f1<90 & field_agg_f0<10 & inrange(f8field_comp_agg,1,10) & f8yrc<.

* Throw out ill-defined fields, recode no-college codes
drop if inlist(90,field_agg_f1,field_agg_f0,f8field_comp_agg)
recode *field*agg* (0 . = 99)
rename (field_agg_f1 field_agg_f0 dum_f1 f8field_comp_agg) (f1 f0 z1 f) // more compact names for key variables

*Find predicted inst, aggregate small institutions
g inst_pred = cond(z1,inst_f1,inst_f0)
lab val inst_pred inst

local nmin 100
egen n_inst = sum(sample) ,by(inst_pred)
replace inst_pred = 99 if n_inst<`nmin' | inst_pred==.
levelsof inst_pred if inst_pred<99 ,local(ips) sep(",")
foreach var of varlist inst_f? inst_compl {
	replace `var'=99 if !inlist(`var',`ips')
}

* Keep only relevant variables
drop offer_pred*
keep  appyear fnr female age immpar ??r_highed far_earnings gpa gpa? f1 field_det_f1 inst_f1 d_f1 z1  offer_f1 f0 field_det_f0 inst_f0  *pred* f f8field_comp_det inst_compl *f8yrc sample 
order appyear fnr female age immpar ??r_highed far_earnings gpa gpa? f1 field_det_f1 inst_f1 d_f1 z1  offer_f1 f0 field_det_f0 inst_f0  *pred* f f8field_comp_det inst_compl *f8yrc sample 
compress
run ${prog}varlabels
save data ,replace
