local sodata /ssb/ursus/a1/finnut/wk48/raw/so/
local nudbdata /ssb/ursus/a1/finnut/wk48/raw/s360/nudb/
local gfile /ssb/ursus/a1/finnut/wk48/g
local inst_link /ssb/ursus/a1/finnut/wk48/inst_link


// Background variables
use fnr nus2000_far_16 nus2000_mor_16 kjoenn fodt_aar invkat using `nudbdata'tab_utd_person ,clear
drop if fnr ==.
bysort fnr: keep if _n==1
tempfile backgr
save `backgr' 
use fnr mor_fnr far_fnr using `nudbdata'tab_alle_snr
drop if fnr ==.
bysort fnr: keep if _n==1
merge 1:1 fnr using `backgr' ,nogen
save `backgr' ,replace

// Course info
u `sodata'studium98_10 ,clear
bysort studie (aar): keep if _n==_N
keep studie utd*
tempfile courses
save `courses'

// GPA thresholds
u `sodata'/poeng1998
g int year = 1998
forv y = 1999/2004 {
	append using `sodata'poeng`y'
	replace year = `y' if year==.
}
replace studienavn = string(studietypenr, "%03.0f") if studietypenr<.
replace navn = string(laerestednr, "%03.0f") if laerestednr<. 
// Uses threshold from main admission round when there is no data from final round
replace vara_ord = hoved_ord  if vara_ord >hoved_ord 
replace vara_ordp= hoved_ordp if vara_ordp>hoved_ordp

rename studienavn studiumnavn
rename navn lstednavn
run ${prog}replace_navn // change some strings for good merging 
bysort year lstednavn studiumnavn : keep if _n==1
keep year lstednavn studiumnavn vara*
tempfile poeng
save `poeng' 


// Put data together
u `sodata'soknad1998
replace laerestednavn = string(floor(studie / 1000), "%03.0f")
replace studiekortnavn = string(mod(studie, 1000), "%03.0f")
forv y = 1999/2004 {
	append using `sodata'soknad`y'
}
sort studie
merge m:1 studie using `courses' ,keep(1 3 4 5) update gen(_mergeomr) 
tab _mergeomr

rename studiekortnavn studiumnavn
rename laerestednavn lstednavn
replace studiumnavn = laerestedkode + studiumnavn if utdtype=="MEDISIN" & aar>1998
replace lstednavn = "Opptakssentralen Medisin" if utdtype=="MEDISIN" & aar>1998
run ${prog}replace_navn
g studiekortnavn = studiumnavn
run ${prog}classify_applied

rename aar year  
replace kvote="ORDP" if inlist(kvote,"ORDU","UVO") // recodes to make consistent over time

// merge in thresholds
// not everything is matched, the remaining are genuinely difficult,
// typically uses admission tests/interviews
merge m:1 year lstednavn studiumnavn using `poeng', nogen keep(master match)

// keeps "valid" applications
keep if kval=="J" & inlist(dokumentasjon, "BEH", "VEN") & studstat=="AKT" // a "valid" application (according to SO)
drop if pri>=16 // option to apply for the introductory semester (if all else fails)

// includes no college as an alternative
preserve
keep fnr year pri studie vara_ord vara_ordp field_*
bysort year fnr : keep if _n==1
replace pri       = 17
recode studie vara_ord* (nonmiss = 0) (miss = 0)
recode field* (nonmiss = 99) (miss = 99)
tempfile upsec
save `upsec'
restore
append using `upsec'


// impute gpa for individuals with incomplete GPA registrations
// the lowest mode GPA will typically be the raw/uncorrected one
// (the course-specific part of GPA is of minor importance)
rename poeng_prim poeng_ordp
foreach v of var poeng_ord poeng_ordp {
	tempvar pmin 
	bys year fnr : egen `pmin' = mode(`v'), minmode
	replace `v' = `pmin' if `v'==.
	drop `pmin'
}
drop if poeng_ordp==. & poeng_ord==. // drop people who still have missing GPA

// keep first (observed) application
bysort fnr (year) : keep if year == year[1]

// drop if people have higher ed degree
g int tellaar = year
merge m:1 fnr tellaar using data_outcomes, nogen keep(1 3) keepusing(bu_kltrinn)
keep if real(bu_kltrinn) <16 

// For each course applied, identifies whether the applicant can compete in
// the "young" applicants' quota, and whether she performs better here, relative
// to the threshold. Then uses admission score and threshold from the "best" quota
g byte eligy    = (poeng_ordp - vara_ordp) > (poeng_ord - vara_ord) & (poeng_ordp - vara_ordp) < .
g gpabound = cond(eligy, vara_ordp , vara_ord)
g gpa      = cond(eligy, poeng_ordp, poeng_ord)
g byte poffer   = gpa >= gpabound
bysort fnr year (pri) : replace poffer = 0 if sum(poffer) > 1

// keep everybody in regular quota
bys fnr year : egen otherquot = max(!inlist(kvote, "ORD", "ORDP", "SPEV", ""))
drop if otherquot

// we cannot predict offer for courses with missing bounds
// and therefore also not for lower ranked courses
// drop all these (alternative would be to drop these people alltogether)
bysort fnr year (pri) : g x = sum(gpabound==.)
drop if x
drop bu_kltrinn x otherquot

// Normalization
bysort year : egen mgpa  = mean(cond(pri==1,gpa,.))
bysort year : egen sdgpa = sd(cond(pri==1,gpa,.))
replace gpa = (gpa - mgpa) / sdgpa
replace gpabound = (gpabound - mgpa) / sdgpa

// find predicted peer gpa
egen npeer   = sum(poffer) if poffer ,by(year laerestedkode field_agg)
egen sumpeer = sum(gpa) if poffer ,by(year laerestedkode field_agg)
g peer_pred = (sumpeer - gpa )/(npeer-1)
drop sumpeer npeer
bysort fnr (peer_pred): replace peer_pred = peer_pred[1]

// merge with background vars
merge m:1 fnr using `backgr' ,keep(1 3) nogen
g byte female = real(kjoenn)-1
g byte age = year-fodt_aar
g byte immpar = inlist(invkat,"B","C")

foreach x in mor far {
	rename (fnr `x'_fnr) (Xfnr fnr)
	g `x'_highed = inrange(real(substr(nus2000_`x'_16,1,1)),6,8)
		
	foreach a in 16 19 {
		replace tellaar = fodt_aar+`a'
		merge m:1 tellaar fnr using data_outcomes ,keep(1 3) keepusing(wyrkinnt) nogen
		merge m:1 tellaar using `gfile' ,keep(1 3) nogen
		g `x'_earnings`a' = wyrkinnt*(kpi2011/kpi)/6500
		drop wyrkinnt g kpi* 
	}
	egen `x'_earnings = rowmean(`x'_earnings1?) 
	replace `x'_earnings = 0 if `x'_earnings == .
	
	rename (Xfnr fnr) (fnr `x'_fnr)
}

// merge with outcomes vars
foreach a in 8 {
	replace tellaar = year+`a'
	merge m:1 tellaar fnr using data_outcomes ,keep(1 3) nogen
	merge m:1 tellaar using `gfile' ,keep(1 3) nogen
	g f`a'yrc = wyrkinnt*(kpi2011/kpi)/6500
	g f`a'yg = wyrkinnt/g
	g lnf`a'yrc = log(f`a'yrc) if wyrkinnt>g
	rename (bu_kltrinn-wyrkinnt) f`a'=
	drop g kpi*
}

// Code institution consistently (applied and completed)
run ${prog}ilabel
replace laerestedkode = "MSH" if laerestedkode == "MSHS" 
replace laerestedkode = "RHS" if laerestedkode == "RVH" 
encode laerestedkode ,g(inst) label(inst)

drop laerestedkode
destring f?hskode ,replace
rename f8hskode hskode
merge m:1 hskode using `inst_link' ,keep(1 3) keepusing(laerestedkode) gen(_m_instl_ink)
encode laerestedkode ,g(inst_compl) label(inst)
drop laerestedkode

qui compress

recode *field*agg* (6=1) (4=2) (5=3) (8=4) (1=5) (2=6) (42=7) (3=8) (44=9) (48=10)
lab def field_agg 1 "Humanities" 2 "Social Science" 3 "Teaching" 4 "Health" 5 "Science" ///
	6 "Enigneering" 7 "Technology" 8 "Business" 9 "Law" 10 "Medicine" 90 "Other" 99 "No college" ,replace
lab val *field*agg* field_agg

save soknad_full, replace
