capture program drop DiscGraph 
program define DiscGraph
	syntax varlist [if] ,[bw(real .1) name(passthru) twoway(string)]
	tempvar force
	
	preserve 
	if "`if'"!="" keep `if'
	
	g `force' = round(d_f1 + `bw' / 2,`bw') - `bw' / 2
	local i = 0
	foreach var of local varlist {
		local i = `i'+1
		tempvar data_`var'

		egen `data_`var'' = mean(`var') ,by(`force' `by')
		bysort `force' `by': replace `data_`var'' = . if _n>1
		
		local plot `plot' ///
		   (lpoly `var' d_f1 if z1==0 ,deg(1) psty(p`i')) ///
		   (lpoly `var' d_f1 if z1==1 ,deg(1) psty(p`i')) ///
		   (scatter `data_`var'' `force' ,psty(p`i'))
		   
		local n = (`i'-1)*2+2
		local ns `ns' `n'
		local legend `legend' label(`n' `"`: var label `var''"')
		
	}	
	local nvars : word count `varlist'
	if `nvars'==1 {
		local op `"ytitle(`"`: var label `varlist''"') legend(off)"'
	}
	else 	      local op `"legend(`legend' order(`ns'))"'
	twoway `plot' , `op' `name' `twoway' ///
	       xline(0, lstyle(foreground) lpat(shortdash) ) ///
	       xti("Distance from threshold in application score (SDs)")	       
	
	restore
end

use data ,clear

* Figure III
g compl_f1 = f == f1
DiscGraph offer_f1 compl_f1 if sample & abs(d_f1)<2 ,name(Fig_III, replace)

* Figure V
reg f8yrc gpa i.mor_highed i.far_highed far_earn immpar // fewer controls than in paper, matters little
predict ypred
DiscGraph ypred if sample & abs(d_f1)<2 ,name(Fig_V, replace)

* Figure Xa
g compl = f<99
DiscGraph compl if f0<48 & abs(d_f1)<2 ,name(Fig_Xa, replace) twoway(yla(0(.2)1))

* Figure IV
local bw .1
replace d_f1 = round(d_f1 + `bw' / 2,`bw') - `bw' / 2
collapse (count) n=appyear ,by(d_f1 z1)
g logn = log(n)-11
DiscGraph logn if abs(d_f1)<2 ,name(Fig_IV, replace) // bw(.25)

* Figure VI
cap program drop RFGraph
program define RFGraph
	syntax =exp if ,psty(passthru) name(passthru)
	
	preserve
	keep `if'
	tempvar cat dec force
	g `cat' `exp'
	bysort z1 `cat' (d_f1): g `dec' = ceil(4*_n/_N)
	egen `force' = mean(d_f1) ,by(z1 `cat' `dec')
	collapse (mean) dv xb res ,by(z1 `cat' `force')
	reshape wide dv xb res ,i(`force') j(`cat')

 	*local dash = cond(`i'==1,"lpatt(solid dash)","")
	local opt psty(`p`i'')
	twoway (line xb* `force' if z1==0, sort `psty') ///
	       (line xb* `force' if z1==1, sort `psty') ///
	       (scatter dv* `force' ,`psty') , `name' xla(-2/2) yla(40(10)80) legend(off) ///
	      xti("Distance from threshold in application score (SDs)") yti("Earnings in USD 1,000")
	restore
end

set matsize 10000
use data, clear 
keep if sample 
g z0 = !z1
tab appyear ,g(Dyear)
tab age ,g(Dage)
drop Dage3 Dyear3

local controls c.(female gpa Dyear* Dage*)
fvunab cvars : `controls'
qui foreach var of local cvars {
	su `var' ,mean
	replace `var' = `var'-r(mean)
}
qui reg f8yrc f0#f1#c.z1 f0#f1 i.f0##(`controls')
predict res if e(sample) ,res
recode `cvars' (nonmissing=0)
predict xb  if e(sample)
g dv = xb + res

RFGraph =z1*100 if 1 ,psty(p1 p1 p1) name("Fig_VIa",replace)
RFGraph =z1*f1 if (z1 & inlist(f1,3,8)) | z0 ,psty(p1 p2 p3 ) name("Fig_VIb",replace)
RFGraph =f0*z0 + f1*z1 if f1==3 & f0==6 ,psty(p2 p4) name("Fig_VIc",replace)
RFGraph =f0*z0 + f1*z1 if f1==3 & f0==2 ,psty(p5 p2) name("Fig_VId",replace)
