global prog /ssb/ursus/a1/finnut/users/kir/fields/prog/ // directory of replication programs
cd /ssb/ursus/a1/finnut/users/kir/fields/wk12 // working directory, all files will be saved here

cap mkdir results

log using results/replication.log ,replace

* Prepares outcome data (completed education and earnings)
qui do ${prog}data_outcomes 
// specify source directories in head of file
// calls classify_completed.do

* Prepares application data, merges with background and outcomes
qui do ${prog}data_applications 
// specify source directories in head of file
// calls replace_navn.do, classify_applied.do, vlabels.do, ilabel.do

* Makes analysis data set (data.dta), finding f1 vs f0 margins
qui do ${prog}data 
// calls varlabels.do

* Makes Table III, Figures I and II
qui do ${prog}descriptives
esttab sample all ,cells("mean(fmt(2)) sd(par)") mti("Sample" "All") lab ti("Table III")

* Makes Figures III, IV, V, VI and Xa
qui do ${prog}rdgraph

* Estimates pay-offs for different specifications, saves results 
qui do ${prog}estimation

* Makes Tables IV, B.I, B.IV and B.VI 
do ${prog}esttables

* Makes Figures VII, VIII, IX, Xb, XI, XII, B.I, B.IV, B.VI and B.VII
qui do ${prog}estfigures

* Estimates pay-off not conditioning on counter-factual, makes Figure B.II, B.III
qui do ${prog}pooled 

* Estimates pay-off to field*institution
qui do ${prog}nonsep
* Makes Table B.V
esttab e? ,nogap indicate("Field=*f*f0" "Inst=*inst_pred") nocons noobs scalar(r2 F_f F_i) sfmt(2 1 1) ti("Table B.V")

* Estimates pay-off to subfields, makes Figure B.V
qui do ${prog}estimation_det

* Tests for homogenous pay-offs and restrictive preferences, makes Tables B.II and B.III
do ${prog}testmodels

qui graph dir 
qui foreach g in `r(list)' {
	graph export results/`g'.eps ,name(`g') replace
}

log close
