set matsize 10000
use data,clear
keep if sample
qui forvalues i=1/10 {
	g f1_`i'=f1==`i'
	g f_`i' =f==`i'
}

local xs c.gpa c.female i.age i.appyear

* Overall test of homogeneous pay-offs
qui ivregress 2sls f8yrc (ib(1).f f0#f = f0#f1#c.z1) f0##(`xs') f1_*,robust
qui testparm i.f0#i.f
noi di "Overall: chi2(`r(df)')=" %5.1f r(chi2) ", p-value=" %5.3f r(p)

* By f0
levelsof f0 ,local(f0s) 
local sum_chi2 = 0
local sum_df = 0
qui foreach ref of local f0s {
	preserve
	ivregress 2sls f8yrc (ib(`ref').f = f1#c.z1) `xs' f1_* ,robust
	est sto e_pooled`ref'
	ivregress 2sls f8yrc (ib(`ref').f = f1#c.z1) `xs' f1_* if f0==`ref',robust 
	est sto e_f0`ref'

	g d = f0==`ref'
	ivregress 2sls f8yrc (ib(`ref').f d#f = d#f1#c.z1) d##(`xs') f1_*  ,robust
	est sto eintx_f0`ref'

	estout . ,cell(b) keep(1.d#*.f) 
	mat b = (r(coefs))'
	local rownames : colnames b
	estout . ,cell(se) keep(1.d#*.f) 
	mata: st_matrix("se",st_matrix("r(coefs)"):^2)
	mat rownames se = `rownames'
	mat V = diag(se)
	
	testparm d#i.f
	
	local sum_chi2 = `sum_chi2' + r(chi2)
	local sum_df = `sum_df' + r(df)
	
	eret post b V ,obs(`e(N)')
	estadd local  cmd "ivregress"
	estadd scalar joint_chi2 = r(chi2)
	estadd scalar joint_p    = r(p)
	est sto e_f0`ref'_test
	
	local sum_chi2 = `sum_chi2'
	
	*noi esttab e_f0`ref'_test ,nogap se b(2) keep(1.d#*.f) noobs scalar(joint_chi2 joint_p) sfmt(2 4)
	restore
}
noi esttab e_f0*_test ,nogap se b(2) keep(1.d#*.f) noobs scalar(joint_chi2 joint_p) sfmt(2 4) ///
	mti(`f0s') order(1.d#1.f) starlevel(* .10 ** .05) ti("Table B.II")
noi di "Sum across f0's: chi2(`sum_df')=" %5.1f `sum_chi2' ", p-value=" %5.3f chi2tail(`sum_df',`sum_chi2') 


* First stages (preferences)
levelsof f ,local(fs)
levelsof f1 ,local(f1s)
levelsof f0 ,local(f0s)

qui foreach f of local fs {
	reg f_`f' f0#f1#c.z1 i.f1 f0##c.(`xs') 
	est sto first_f`f'
}
qui suest first_f* ,robust

local test "" 
qui foreach f0 of local f0s {
	local test_f0`f0' ""
	foreach f of local fs {
		if `f'==`f0' continue
		foreach f1 of local f1s {
			if inlist(`f1',`f',`f0') continue
		
			local test_f0`f0' `test_f0`f0'' ([first_f`f'_mean]:`f0'.f0#`f1'.f1#c.z1)
		}
	}
	*di "test `test_f0`f0''"
	qui test `test_f0`f0''
	noi di %5s "`f0':" "chi2(" r(df) ")=" %7.1f r(chi2) ", p-value=" %6.4f r(p)
}
qui test `test_f01' `test_f02' `test_f03' `test_f04' `test_f05' ///
     `test_f06' `test_f08' `test_f42' `test_f44'
noi di %5s "Overall:" "chi2(" r(df) ")=" %7.1f r(chi2) ", p-value=" %6.4f r(p)
